![](https://raw.githubusercontent.com/TwitchIO/TwitchIO/main/logo.png)
[![](https://img.shields.io/badge/Python-3.11%20%7C%203.12%20%7C%203.13-blue.svg)](https://www.python.org)
![Pyright Strict](https://img.shields.io/badge/Pyright-Strict-b8dbb4)
![GitHub License](https://img.shields.io/github/license/PythonistaGuild/twitchio)

A fully featured, powerful async Python library for the Twitch API and EventSub with modern Object-Orientated design
and stateful objects.

TwitchIO provides ease of use when accessing the Twitch API with powerful extensions for chat commands, web-frameworks and overlays 
with hot-reloadable modules to help create and manage bots, backends, websites and other applications on Twitch.

**Features:**

- Modern ``async`` Python using ``asyncio``
- Fully annotated and complies with the ``pyright`` strict type-checker
- Intuitive with ease of use, using modern object orientated design
- Conduit support for scaling and EventSub continuity
- Feature full including extensions for ``chat bots``, running ``routine tasks`` and ``overlays`` on stream
- Easily manage ``OAuth Tokens`` and data
- Built-in ``EventSub`` support via ``Webhook``, ``Websockets`` and ``Conduits``.

### Documentation
[Documentation](https://twitchio.dev/)
   
Getting Started
--------------------------------
[Installing](https://twitchio.dev/en/latest/getting-started/installing.html)

[Quickstart](https://twitchio.dev/en/latest/getting-started/quickstart.html)

[Examples](/examples)

Useful Links
--------------
[Scope/OAuth URL Generator](https://chillymosh.com/tools/twitch-scopes/)

[Twitch API Documentation](https://dev.twitch.tv/docs/)

[Twitch Developer Console](https://dev.twitch.tv/console)

### Support
For support using TwitchIO, please join the official [support server](https://discord.gg/RAKc3HF) on [Discord](https://discord.com/)

[![Discord Banner](https://discordapp.com/api/guilds/490948346773635102/widget.png?style=banner2)](https://discord.gg/RAKc3HF)
